#pragma once

#include <torch/csrc/python_headers.h>

namespace torch::mps {

PyMethodDef* python_functions();

} // namespace torch::mps
